/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Cantor.R.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "radaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class RAdaptor
 */

RAdaptor::RAdaptor(RServer *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

RAdaptor::~RAdaptor()
{
    // destructor
}

void RAdaptor::answerRequest(const QString &answer)
{
    // handle method call org.kde.Cantor.R.answerRequest
    parent()->answerRequest(answer);
}

void RAdaptor::runCommand(const QString &cmd, bool internal)
{
    // handle method call org.kde.Cantor.R.runCommand
    parent()->runCommand(cmd, internal);
}


#include "moc_radaptor.cpp"
