/********************************************************************************
** Form generated from reading UI file 'backendchooser.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKENDCHOOSER_H
#define UI_BACKENDCHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BackendChooserBase
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QListWidget *backendList;
    QCheckBox *makeDefault;
    QTextBrowser *descriptionView;

    void setupUi(QWidget *BackendChooserBase)
    {
        if (BackendChooserBase->objectName().isEmpty())
            BackendChooserBase->setObjectName("BackendChooserBase");
        BackendChooserBase->resize(620, 461);
        gridLayout = new QGridLayout(BackendChooserBase);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(BackendChooserBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 1, 1, 1);

        backendList = new QListWidget(BackendChooserBase);
        backendList->setObjectName("backendList");
        backendList->setFlow(QListView::TopToBottom);
        backendList->setResizeMode(QListView::Adjust);
        backendList->setViewMode(QListView::ListMode);

        gridLayout->addWidget(backendList, 0, 0, 1, 1);

        makeDefault = new QCheckBox(BackendChooserBase);
        makeDefault->setObjectName("makeDefault");

        gridLayout->addWidget(makeDefault, 1, 0, 1, 1);

        descriptionView = new QTextBrowser(BackendChooserBase);
        descriptionView->setObjectName("descriptionView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(descriptionView->sizePolicy().hasHeightForWidth());
        descriptionView->setSizePolicy(sizePolicy);

        gridLayout->addWidget(descriptionView, 0, 1, 1, 1);


        retranslateUi(BackendChooserBase);

        QMetaObject::connectSlotsByName(BackendChooserBase);
    } // setupUi

    void retranslateUi(QWidget *BackendChooserBase)
    {
        makeDefault->setText(tr2i18n("Make this the default backend", nullptr));
        (void)BackendChooserBase;
    } // retranslateUi

};

namespace Ui {
    class BackendChooserBase: public Ui_BackendChooserBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BACKENDCHOOSER_H

