/********************************************************************************
** Form generated from reading UI file 'plot2ddlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOT2DDLG_H
#define UI_PLOT2DDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Plot2dAssistantBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KLineEdit *expression;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    KLineEdit *variable;
    QLabel *label_3;
    KLineEdit *min;
    QLabel *label_4;
    KLineEdit *max;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *Plot2dAssistantBase)
    {
        if (Plot2dAssistantBase->objectName().isEmpty())
            Plot2dAssistantBase->setObjectName("Plot2dAssistantBase");
        Plot2dAssistantBase->resize(314, 349);
        verticalLayout = new QVBoxLayout(Plot2dAssistantBase);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(Plot2dAssistantBase);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        expression = new KLineEdit(Plot2dAssistantBase);
        expression->setObjectName("expression");

        horizontalLayout->addWidget(expression);


        verticalLayout->addLayout(horizontalLayout);

        groupBox = new QGroupBox(Plot2dAssistantBase);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        groupBox->setCheckable(false);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        variable = new KLineEdit(groupBox);
        variable->setObjectName("variable");

        gridLayout->addWidget(variable, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        min = new KLineEdit(groupBox);
        min->setObjectName("min");

        gridLayout->addWidget(min, 1, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        max = new KLineEdit(groupBox);
        max->setObjectName("max");

        gridLayout->addWidget(max, 2, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(Plot2dAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(expression, variable);
        QWidget::setTabOrder(variable, min);
        QWidget::setTabOrder(min, max);

        retranslateUi(Plot2dAssistantBase);

        QMetaObject::connectSlotsByName(Plot2dAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *Plot2dAssistantBase)
    {
        label->setText(tr2i18n("Expression:", nullptr));
        groupBox->setTitle(tr2i18n("Variable", nullptr));
        label_2->setText(tr2i18n("Name", nullptr));
        label_3->setText(tr2i18n("Minimum:", nullptr));
        label_4->setText(tr2i18n("Maximum:", nullptr));
        (void)Plot2dAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class Plot2dAssistantBase: public Ui_Plot2dAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOT2DDLG_H

