/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "keditlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PythonSettingsBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLabel *lVariableManagement;
    QCheckBox *kcfg_variableManagement;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_4;
    QLabel *lPlotIntegration;
    QCheckBox *kcfg_integratePlots;
    QLabel *label_5;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *lPlotWidth;
    QDoubleSpinBox *kcfg_plotWidth;
    QSpacerItem *horizontalSpacer;
    QLabel *lPlotHeight;
    QDoubleSpinBox *kcfg_plotHeight;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_3;
    QComboBox *kcfg_inlinePlotFormat;
    QLabel *label4;
    KComboBox *kcfg_plotExtenstionGraphicPackage;
    QSpacerItem *verticalSpacer;
    QWidget *tabAutorun;
    QVBoxLayout *verticalLayout;
    QLabel *lAutorun;
    KEditListWidget *kcfg_autorunScripts;
    QWidget *tabDocumentation;

    void setupUi(QWidget *PythonSettingsBase)
    {
        if (PythonSettingsBase->objectName().isEmpty())
            PythonSettingsBase->setObjectName("PythonSettingsBase");
        PythonSettingsBase->resize(572, 351);
        verticalLayout_2 = new QVBoxLayout(PythonSettingsBase);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(6, 6, 6, 6);
        tabWidget = new QTabWidget(PythonSettingsBase);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(false);
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        lVariableManagement = new QLabel(tabGeneral);
        lVariableManagement->setObjectName("lVariableManagement");

        gridLayout->addWidget(lVariableManagement, 0, 0, 1, 1);

        kcfg_variableManagement = new QCheckBox(tabGeneral);
        kcfg_variableManagement->setObjectName("kcfg_variableManagement");

        gridLayout->addWidget(kcfg_variableManagement, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(136, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 1, 0, 1, 1);

        label_4 = new QLabel(tabGeneral);
        label_4->setObjectName("label_4");
        QFont font;
        font.setBold(true);
        label_4->setFont(font);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        lPlotIntegration = new QLabel(tabGeneral);
        lPlotIntegration->setObjectName("lPlotIntegration");

        gridLayout->addWidget(lPlotIntegration, 3, 0, 1, 1);

        kcfg_integratePlots = new QCheckBox(tabGeneral);
        kcfg_integratePlots->setObjectName("kcfg_integratePlots");

        gridLayout->addWidget(kcfg_integratePlots, 3, 1, 1, 1);

        label_5 = new QLabel(tabGeneral);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        frame = new QFrame(tabGeneral);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        lPlotWidth = new QLabel(frame);
        lPlotWidth->setObjectName("lPlotWidth");

        horizontalLayout->addWidget(lPlotWidth);

        kcfg_plotWidth = new QDoubleSpinBox(frame);
        kcfg_plotWidth->setObjectName("kcfg_plotWidth");

        horizontalLayout->addWidget(kcfg_plotWidth);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        lPlotHeight = new QLabel(frame);
        lPlotHeight->setObjectName("lPlotHeight");

        horizontalLayout->addWidget(lPlotHeight);

        kcfg_plotHeight = new QDoubleSpinBox(frame);
        kcfg_plotHeight->setObjectName("kcfg_plotHeight");

        horizontalLayout->addWidget(kcfg_plotHeight);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addWidget(frame, 4, 1, 1, 1);

        label_3 = new QLabel(tabGeneral);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 5, 0, 1, 1);

        kcfg_inlinePlotFormat = new QComboBox(tabGeneral);
        kcfg_inlinePlotFormat->addItem(QString());
        kcfg_inlinePlotFormat->addItem(QString::fromUtf8("SVG"));
        kcfg_inlinePlotFormat->addItem(QString::fromUtf8("PNG"));
        kcfg_inlinePlotFormat->setObjectName("kcfg_inlinePlotFormat");

        gridLayout->addWidget(kcfg_inlinePlotFormat, 5, 1, 1, 1);

        label4 = new QLabel(tabGeneral);
        label4->setObjectName("label4");

        gridLayout->addWidget(label4, 6, 0, 1, 1);

        kcfg_plotExtenstionGraphicPackage = new KComboBox(tabGeneral);
        kcfg_plotExtenstionGraphicPackage->addItem(QString());
        kcfg_plotExtenstionGraphicPackage->addItem(QString());
        kcfg_plotExtenstionGraphicPackage->addItem(QString());
        kcfg_plotExtenstionGraphicPackage->addItem(QString());
        kcfg_plotExtenstionGraphicPackage->addItem(QString());
        kcfg_plotExtenstionGraphicPackage->setObjectName("kcfg_plotExtenstionGraphicPackage");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_plotExtenstionGraphicPackage->sizePolicy().hasHeightForWidth());
        kcfg_plotExtenstionGraphicPackage->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_plotExtenstionGraphicPackage, 6, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabAutorun = new QWidget();
        tabAutorun->setObjectName("tabAutorun");
        verticalLayout = new QVBoxLayout(tabAutorun);
        verticalLayout->setObjectName("verticalLayout");
        lAutorun = new QLabel(tabAutorun);
        lAutorun->setObjectName("lAutorun");
        lAutorun->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(lAutorun);

        kcfg_autorunScripts = new KEditListWidget(tabAutorun);
        kcfg_autorunScripts->setObjectName("kcfg_autorunScripts");

        verticalLayout->addWidget(kcfg_autorunScripts);

        tabWidget->addTab(tabAutorun, QString());
        tabDocumentation = new QWidget();
        tabDocumentation->setObjectName("tabDocumentation");
        tabWidget->addTab(tabDocumentation, QString());

        verticalLayout_2->addWidget(tabWidget);


        retranslateUi(PythonSettingsBase);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PythonSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *PythonSettingsBase)
    {
        lVariableManagement->setText(tr2i18n("Variable Management:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_variableManagement->setToolTip(tr2i18n("Monitor the creation and destruction of variables and show the existing variables in the variable panel.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_variableManagement->setText(tr2i18n("Enabled", nullptr));
        label_4->setText(tr2i18n("Plots", nullptr));
        lPlotIntegration->setText(tr2i18n("Integrated:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_integratePlots->setToolTip(tr2i18n("If enabled, plots will be shown inside of the worksheet. Otherwise, plots will be shown in an external window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_integratePlots->setText(tr2i18n("Enabled", nullptr));
        label_5->setText(tr2i18n("Size:", nullptr));
        lPlotWidth->setText(tr2i18n("width:", nullptr));
        kcfg_plotWidth->setSuffix(tr2i18n("cm", nullptr));
        lPlotHeight->setText(tr2i18n("height:", nullptr));
        kcfg_plotHeight->setSuffix(tr2i18n("cm", nullptr));
        label_3->setText(tr2i18n("Image Format:", nullptr));
        kcfg_inlinePlotFormat->setItemText(0, tr2i18n("PDF", nullptr));

#if QT_CONFIG(tooltip)
        label4->setToolTip(tr2i18n("Graphic package to be used in the Plot Assistant", nullptr));
#endif // QT_CONFIG(tooltip)
        label4->setText(tr2i18n("Plot Assistant:", nullptr));
        kcfg_plotExtenstionGraphicPackage->setItemText(0, tr2i18n("matplotlib", nullptr));
        kcfg_plotExtenstionGraphicPackage->setItemText(1, tr2i18n("pylab", nullptr));
        kcfg_plotExtenstionGraphicPackage->setItemText(2, tr2i18n("plot.ly", nullptr));
        kcfg_plotExtenstionGraphicPackage->setItemText(3, tr2i18n("GR", nullptr));
        kcfg_plotExtenstionGraphicPackage->setItemText(4, tr2i18n("bokeh", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_plotExtenstionGraphicPackage->setToolTip(tr2i18n("Graphic package to be used in the Plot Assistant", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lAutorun->setText(tr2i18n("Commands to autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAutorun), tr2i18n("Autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDocumentation), tr2i18n("Documentation", nullptr));
        (void)PythonSettingsBase;
    } // retranslateUi

};

namespace Ui {
    class PythonSettingsBase: public Ui_PythonSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

