/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsBase
{
public:
    QGridLayout *gridLayout;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;
    QCheckBox *kcfg_CompletionDefault;
    QLabel *label_2;
    QLabel *label;
    QLabel *label_theme;
    QSpinBox *kcfg_VisibleLinesLimit;
    QCheckBox *kcfg_TypesetDefault;
    QLabel *VisibleLinesLimit_label;
    KComboBox *kcfg_DefaultBackend;
    KComboBox *kcfg_DefaultTheme;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *kcfg_AnimationDefault;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *kcfg_EmbeddedMathDefault;
    QCheckBox *kcfg_AutoEval;
    QLabel *label_3;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer_2;
    QCheckBox *kcfg_StoreTextEntryFormatting;
    QLabel *label_5;
    QCheckBox *kcfg_UseOldCantorEntriesIndent;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_WarnAboutSessionRestart;
    QCheckBox *kcfg_ShowMathRenderError;
    QCheckBox *kcfg_ExpressionNumberingDefault;
    QCheckBox *kcfg_HighlightDefault;
    QCheckBox *kcfg_WarnAboutEntryDelete;

    void setupUi(QWidget *SettingsBase)
    {
        if (SettingsBase->objectName().isEmpty())
            SettingsBase->setObjectName("SettingsBase");
        SettingsBase->resize(528, 586);
        gridLayout = new QGridLayout(SettingsBase);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(SettingsBase);
        label_4->setObjectName("label_4");
        QFont font;
        font.setBold(true);
        label_4->setFont(font);

        gridLayout->addWidget(label_4, 14, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 22, 0, 1, 1);

        kcfg_CompletionDefault = new QCheckBox(SettingsBase);
        kcfg_CompletionDefault->setObjectName("kcfg_CompletionDefault");

        gridLayout->addWidget(kcfg_CompletionDefault, 7, 0, 1, 1);

        label_2 = new QLabel(SettingsBase);
        label_2->setObjectName("label_2");
        label_2->setFont(font);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        label = new QLabel(SettingsBase);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_theme = new QLabel(SettingsBase);
        label_theme->setObjectName("label_theme");

        gridLayout->addWidget(label_theme, 4, 0, 1, 1);

        kcfg_VisibleLinesLimit = new QSpinBox(SettingsBase);
        kcfg_VisibleLinesLimit->setObjectName("kcfg_VisibleLinesLimit");
        kcfg_VisibleLinesLimit->setMaximum(10000);
        kcfg_VisibleLinesLimit->setValue(0);

        gridLayout->addWidget(kcfg_VisibleLinesLimit, 17, 5, 1, 1);

        kcfg_TypesetDefault = new QCheckBox(SettingsBase);
        kcfg_TypesetDefault->setObjectName("kcfg_TypesetDefault");

        gridLayout->addWidget(kcfg_TypesetDefault, 5, 0, 1, 2);

        VisibleLinesLimit_label = new QLabel(SettingsBase);
        VisibleLinesLimit_label->setObjectName("VisibleLinesLimit_label");

        gridLayout->addWidget(VisibleLinesLimit_label, 17, 0, 1, 4);

        kcfg_DefaultBackend = new KComboBox(SettingsBase);
        kcfg_DefaultBackend->setObjectName("kcfg_DefaultBackend");
        kcfg_DefaultBackend->setEditable(true);

        gridLayout->addWidget(kcfg_DefaultBackend, 1, 3, 1, 3);

        kcfg_DefaultTheme = new KComboBox(SettingsBase);
        kcfg_DefaultTheme->setObjectName("kcfg_DefaultTheme");
        kcfg_DefaultTheme->setEditable(false);

        gridLayout->addWidget(kcfg_DefaultTheme, 4, 3, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 2, 2, 1, 1);

        kcfg_AnimationDefault = new QCheckBox(SettingsBase);
        kcfg_AnimationDefault->setObjectName("kcfg_AnimationDefault");

        gridLayout->addWidget(kcfg_AnimationDefault, 9, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(92, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 17, 4, 1, 1);

        kcfg_EmbeddedMathDefault = new QCheckBox(SettingsBase);
        kcfg_EmbeddedMathDefault->setObjectName("kcfg_EmbeddedMathDefault");

        gridLayout->addWidget(kcfg_EmbeddedMathDefault, 20, 0, 1, 3);

        kcfg_AutoEval = new QCheckBox(SettingsBase);
        kcfg_AutoEval->setObjectName("kcfg_AutoEval");

        gridLayout->addWidget(kcfg_AutoEval, 16, 0, 1, 3);

        label_3 = new QLabel(SettingsBase);
        label_3->setObjectName("label_3");
        label_3->setFont(font);

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 18, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 13, 1, 1, 1);

        kcfg_StoreTextEntryFormatting = new QCheckBox(SettingsBase);
        kcfg_StoreTextEntryFormatting->setObjectName("kcfg_StoreTextEntryFormatting");

        gridLayout->addWidget(kcfg_StoreTextEntryFormatting, 12, 0, 1, 6);

        label_5 = new QLabel(SettingsBase);
        label_5->setObjectName("label_5");
        label_5->setFont(font);

        gridLayout->addWidget(label_5, 19, 0, 1, 1);

        kcfg_UseOldCantorEntriesIndent = new QCheckBox(SettingsBase);
        kcfg_UseOldCantorEntriesIndent->setObjectName("kcfg_UseOldCantorEntriesIndent");

        gridLayout->addWidget(kcfg_UseOldCantorEntriesIndent, 11, 0, 1, 3);

        horizontalSpacer = new QSpacerItem(188, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 2);

        kcfg_WarnAboutSessionRestart = new QCheckBox(SettingsBase);
        kcfg_WarnAboutSessionRestart->setObjectName("kcfg_WarnAboutSessionRestart");

        gridLayout->addWidget(kcfg_WarnAboutSessionRestart, 15, 0, 1, 4);

        kcfg_ShowMathRenderError = new QCheckBox(SettingsBase);
        kcfg_ShowMathRenderError->setObjectName("kcfg_ShowMathRenderError");

        gridLayout->addWidget(kcfg_ShowMathRenderError, 21, 0, 1, 5);

        kcfg_ExpressionNumberingDefault = new QCheckBox(SettingsBase);
        kcfg_ExpressionNumberingDefault->setObjectName("kcfg_ExpressionNumberingDefault");

        gridLayout->addWidget(kcfg_ExpressionNumberingDefault, 8, 0, 1, 1);

        kcfg_HighlightDefault = new QCheckBox(SettingsBase);
        kcfg_HighlightDefault->setObjectName("kcfg_HighlightDefault");

        gridLayout->addWidget(kcfg_HighlightDefault, 6, 0, 1, 2);

        kcfg_WarnAboutEntryDelete = new QCheckBox(SettingsBase);
        kcfg_WarnAboutEntryDelete->setObjectName("kcfg_WarnAboutEntryDelete");

        gridLayout->addWidget(kcfg_WarnAboutEntryDelete, 10, 0, 1, 1);


        retranslateUi(SettingsBase);

        QMetaObject::connectSlotsByName(SettingsBase);
    } // setupUi

    void retranslateUi(QWidget *SettingsBase)
    {
        label_4->setText(tr2i18n("Evaluation:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_CompletionDefault->setToolTip(tr2i18n("Enable syntax completion", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_CompletionDefault->setText(tr2i18n("Completion", nullptr));
        label_2->setText(tr2i18n("Startup:", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Create a new worksheet for the selected backend system. If none is selected, the user is asked about which system to use on startup.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Default Backend:", nullptr));
#if QT_CONFIG(tooltip)
        label_theme->setToolTip(tr2i18n("Default editor color theme for new worksheets", nullptr));
#endif // QT_CONFIG(tooltip)
        label_theme->setText(tr2i18n("Default Theme:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_VisibleLinesLimit->setToolTip(tr2i18n("Maximal number of visible rows in the result of a command entry. Use 0 to work without limitations.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_TypesetDefault->setToolTip(tr2i18n("Enable LaTeX typesetting for the results of the calculations, if supported by the backend system", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_TypesetDefault->setText(tr2i18n("LaTeX typesetting", nullptr));
#if QT_CONFIG(tooltip)
        VisibleLinesLimit_label->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        VisibleLinesLimit_label->setText(tr2i18n("Number of rows in the result (0 for unlimited):", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_DefaultBackend->setToolTip(tr2i18n("Create a new worksheet for the selected backend system. If none is selected, the user is asked about which system to use on startup.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_DefaultTheme->setToolTip(tr2i18n("Default editor color theme for new worksheets", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_AnimationDefault->setToolTip(tr2i18n("Enable animation effects in the worksheet", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AnimationDefault->setText(tr2i18n("Animations", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_EmbeddedMathDefault->setToolTip(tr2i18n("Enable LaTeX typesetting for mathematical expressions in Markdown entries", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_EmbeddedMathDefault->setText(tr2i18n("Mathematical expressions via LaTeX", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoEval->setToolTip(tr2i18n("If enabled, all entries below the current one will be evaluated automatically", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AutoEval->setText(tr2i18n("Reevaluate entries automatically", nullptr));
        label_3->setText(tr2i18n("Worksheet:", nullptr));
        kcfg_StoreTextEntryFormatting->setText(tr2i18n("Use rich text format for text entries when saving in Jupyter Notebook Format", nullptr));
        label_5->setText(tr2i18n("Markdown:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_UseOldCantorEntriesIndent->setToolTip(tr2i18n("If enabled, text entries are aligned at the worksheet border and not at the prompt border", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_UseOldCantorEntriesIndent->setText(tr2i18n("Don't indent text entries", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_WarnAboutSessionRestart->setToolTip(tr2i18n("If enabled, the user will be asked for confirmation prior to restarting the backend system", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_WarnAboutSessionRestart->setText(tr2i18n("Ask for confirmation when restarting the backend", nullptr));
        kcfg_ShowMathRenderError->setText(tr2i18n("Notify about render failures for mathematical expressions", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ExpressionNumberingDefault->setToolTip(tr2i18n("Show line numbers", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ExpressionNumberingDefault->setText(tr2i18n("Line numbers", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HighlightDefault->setToolTip(tr2i18n("Enable syntax highlighting", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_HighlightDefault->setText(tr2i18n("Syntax highlighting", nullptr));
        kcfg_WarnAboutEntryDelete->setText(tr2i18n("Ask for confirmation when deleting entries", nullptr));
        (void)SettingsBase;
    } // retranslateUi

};

namespace Ui {
    class SettingsBase: public Ui_SettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

