/********************************************************************************
** Form generated from reading UI file 'creatematrixdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEMATRIXDLG_H
#define UI_CREATEMATRIXDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CreateMatrixAssistantBase
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *columns;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *rows;
    QTableWidget *values;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *CreateMatrixAssistantBase)
    {
        if (CreateMatrixAssistantBase->objectName().isEmpty())
            CreateMatrixAssistantBase->setObjectName("CreateMatrixAssistantBase");
        CreateMatrixAssistantBase->resize(451, 210);
        gridLayout = new QGridLayout(CreateMatrixAssistantBase);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(CreateMatrixAssistantBase);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        columns = new QSpinBox(CreateMatrixAssistantBase);
        columns->setObjectName("columns");
        columns->setValue(3);

        horizontalLayout_2->addWidget(columns);


        gridLayout->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(CreateMatrixAssistantBase);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        rows = new QSpinBox(CreateMatrixAssistantBase);
        rows->setObjectName("rows");
        rows->setValue(3);

        horizontalLayout->addWidget(rows);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        values = new QTableWidget(CreateMatrixAssistantBase);
        if (values->columnCount() < 3)
            values->setColumnCount(3);
        if (values->rowCount() < 3)
            values->setRowCount(3);
        values->setObjectName("values");
        values->setRowCount(3);
        values->setColumnCount(3);

        gridLayout->addWidget(values, 1, 0, 1, 2);

        buttonBox = new QDialogButtonBox(CreateMatrixAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 1);


        retranslateUi(CreateMatrixAssistantBase);

        QMetaObject::connectSlotsByName(CreateMatrixAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *CreateMatrixAssistantBase)
    {
        label_2->setText(tr2i18n("Columns:", nullptr));
        label->setText(tr2i18n("Rows:", nullptr));
        (void)CreateMatrixAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class CreateMatrixAssistantBase: public Ui_CreateMatrixAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREATEMATRIXDLG_H

