/********************************************************************************
** Form generated from reading UI file 'standardsearchbar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STANDARDSEARCHBAR_H
#define UI_STANDARDSEARCHBAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_StandardSearchBar
{
public:
    QHBoxLayout *horizontalLayout_2;
    QHBoxLayout *horizontalLayout;
    QToolButton *close;
    KLineEdit *pattern;
    QPushButton *next;
    QPushButton *previous;
    QToolButton *matchCase;
    KSqueezedTextLabel *status;
    QToolButton *openExtended;

    void setupUi(QWidget *StandardSearchBar)
    {
        if (StandardSearchBar->objectName().isEmpty())
            StandardSearchBar->setObjectName("StandardSearchBar");
        StandardSearchBar->resize(736, 34);
        horizontalLayout_2 = new QHBoxLayout(StandardSearchBar);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        close = new QToolButton(StandardSearchBar);
        close->setObjectName("close");
        close->setAutoRaise(true);

        horizontalLayout->addWidget(close);

        pattern = new KLineEdit(StandardSearchBar);
        pattern->setObjectName("pattern");
        pattern->setClearButtonEnabled(true);
        pattern->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout->addWidget(pattern);

        next = new QPushButton(StandardSearchBar);
        next->setObjectName("next");

        horizontalLayout->addWidget(next);

        previous = new QPushButton(StandardSearchBar);
        previous->setObjectName("previous");

        horizontalLayout->addWidget(previous);

        matchCase = new QToolButton(StandardSearchBar);
        matchCase->setObjectName("matchCase");
        matchCase->setCheckable(true);

        horizontalLayout->addWidget(matchCase);

        status = new KSqueezedTextLabel(StandardSearchBar);
        status->setObjectName("status");
        status->setAlignment(Qt::AlignCenter);
        status->setMaximumSize(QSize(160, 16777215));

        horizontalLayout->addWidget(status);

        openExtended = new QToolButton(StandardSearchBar);
        openExtended->setObjectName("openExtended");
        openExtended->setAutoRaise(true);

        horizontalLayout->addWidget(openExtended);


        horizontalLayout_2->addLayout(horizontalLayout);

        QWidget::setTabOrder(pattern, next);
        QWidget::setTabOrder(next, previous);
        QWidget::setTabOrder(previous, matchCase);
        QWidget::setTabOrder(matchCase, openExtended);
        QWidget::setTabOrder(openExtended, close);

        retranslateUi(StandardSearchBar);

        QMetaObject::connectSlotsByName(StandardSearchBar);
    } // setupUi

    void retranslateUi(QWidget *StandardSearchBar)
    {
        StandardSearchBar->setWindowTitle(tr2i18n("SearchBar", nullptr));
        close->setText(tr2i18n("...", nullptr));
        pattern->setPlaceholderText(tr2i18n("Find\342\200\246", nullptr));
        next->setText(tr2i18n("&Next", nullptr));
        previous->setText(tr2i18n("&Previous", nullptr));
        matchCase->setText(tr2i18n("&Match case", nullptr));
        openExtended->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StandardSearchBar: public Ui_StandardSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STANDARDSEARCHBAR_H

