/****************************************************************************
** Meta object code from reading C++ file 'cantor_part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.04.3/src/cantor_part.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cantor_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10CantorPartE_t {};
} // unnamed namespace

template <> constexpr inline auto CantorPart::qt_create_metaobjectdata<qt_meta_tag_ZN10CantorPartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CantorPart",
        "setCaption",
        "",
        "caption",
        "QIcon",
        "icon",
        "showHelp",
        "hierarchyChanged",
        "QList<int>",
        "hierarhyEntryNameChange",
        "name",
        "searchName",
        "depth",
        "worksheetSave",
        "QUrl",
        "setBackendName",
        "requestScrollToHierarchyEntry",
        "settingsChanges",
        "requestDocumentation",
        "keyword",
        "updateCaption",
        "fileSaveAs",
        "fileSavePlain",
        "exportToPDF",
        "exportToLatex",
        "evaluateOrInterrupt",
        "restartBackend",
        "zoomValueEdited",
        "updateZoomWidgetValue",
        "enableTypesetting",
        "showBackendHelp",
        "print",
        "printPreview",
        "worksheetStatusChanged",
        "Cantor::Session::Status",
        "showSessionError",
        "worksheetSessionLoginStarted",
        "worksheetSessionLoginDone",
        "initialized",
        "runCommand",
        "runAssistant",
        "publishWorksheet",
        "showScriptEditor",
        "scriptEditorClosed",
        "runScript",
        "showSearchBar",
        "showExtendedSearchBar",
        "findNext",
        "findPrev",
        "searchBarDeleted",
        "setStatusMessage",
        "showImportantStatusMessage",
        "blockStatusBar",
        "unblockStatusBar",
        "documentationRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setCaption'
        QtMocHelpers::SignalData<void(const QString &, const QIcon &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'showHelp'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'hierarchyChanged'
        QtMocHelpers::SignalData<void(QStringList, QStringList, QList<int>)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QStringList, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'hierarhyEntryNameChange'
        QtMocHelpers::SignalData<void(QString, QString, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'worksheetSave'
        QtMocHelpers::SignalData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'setBackendName'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'requestScrollToHierarchyEntry'
        QtMocHelpers::SignalData<void(QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'settingsChanges'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestDocumentation'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'updateCaption'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fileSaveAs'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fileSavePlain'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'exportToPDF'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'exportToLatex'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'evaluateOrInterrupt'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'restartBackend'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'zoomValueEdited'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'updateZoomWidgetValue'
        QtMocHelpers::SlotData<void(double)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'enableTypesetting'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showBackendHelp'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'worksheetStatusChanged'
        QtMocHelpers::SlotData<void(Cantor::Session::Status)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Slot 'showSessionError'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'worksheetSessionLoginStarted'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'worksheetSessionLoginDone'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'initialized'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'runAssistant'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'publishWorksheet'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showScriptEditor'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'scriptEditorClosed'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'runScript'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'showSearchBar'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showExtendedSearchBar'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'findNext'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'findPrev'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'searchBarDeleted'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setStatusMessage'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'showImportantStatusMessage'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'blockStatusBar'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'unblockStatusBar'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'documentationRequested'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CantorPart, qt_meta_tag_ZN10CantorPartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CantorPart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CantorPartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CantorPartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10CantorPartE_t>.metaTypes,
    nullptr
} };

void CantorPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CantorPart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2]))); break;
        case 1: _t->showHelp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->hierarchyChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 3: _t->hierarhyEntryNameChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->worksheetSave((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->setBackendName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->requestScrollToHierarchyEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->settingsChanges(); break;
        case 8: _t->requestDocumentation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->updateCaption(); break;
        case 10: _t->fileSaveAs(); break;
        case 11: _t->fileSavePlain(); break;
        case 12: _t->exportToPDF(); break;
        case 13: _t->exportToLatex(); break;
        case 14: _t->evaluateOrInterrupt(); break;
        case 15: _t->restartBackend(); break;
        case 16: _t->zoomValueEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->updateZoomWidgetValue((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->enableTypesetting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->showBackendHelp(); break;
        case 20: _t->print(); break;
        case 21: _t->printPreview(); break;
        case 22: _t->worksheetStatusChanged((*reinterpret_cast<std::add_pointer_t<Cantor::Session::Status>>(_a[1]))); break;
        case 23: _t->showSessionError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->worksheetSessionLoginStarted(); break;
        case 25: _t->worksheetSessionLoginDone(); break;
        case 26: _t->initialized(); break;
        case 27: _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->runAssistant(); break;
        case 29: _t->publishWorksheet(); break;
        case 30: _t->showScriptEditor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->scriptEditorClosed(); break;
        case 32: _t->runScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->showSearchBar(); break;
        case 34: _t->showExtendedSearchBar(); break;
        case 35: _t->findNext(); break;
        case 36: _t->findPrev(); break;
        case 37: _t->searchBarDeleted(); break;
        case 38: _t->setStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->showImportantStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->blockStatusBar(); break;
        case 41: _t->unblockStatusBar(); break;
        case 42: _t->documentationRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(const QString & , const QIcon & )>(_a, &CantorPart::setCaption, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(const QString & )>(_a, &CantorPart::showHelp, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(QStringList , QStringList , QList<int> )>(_a, &CantorPart::hierarchyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(QString , QString , int )>(_a, &CantorPart::hierarhyEntryNameChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(const QUrl & )>(_a, &CantorPart::worksheetSave, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(const QString & )>(_a, &CantorPart::setBackendName, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(QString )>(_a, &CantorPart::requestScrollToHierarchyEntry, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)()>(_a, &CantorPart::settingsChanges, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorPart::*)(const QString & )>(_a, &CantorPart::requestDocumentation, 8))
            return;
    }
}

const QMetaObject *CantorPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CantorPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CantorPartE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int CantorPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void CantorPart::setCaption(const QString & _t1, const QIcon & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void CantorPart::showHelp(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CantorPart::hierarchyChanged(QStringList _t1, QStringList _t2, QList<int> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void CantorPart::hierarhyEntryNameChange(QString _t1, QString _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void CantorPart::worksheetSave(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CantorPart::setBackendName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CantorPart::requestScrollToHierarchyEntry(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CantorPart::settingsChanges()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CantorPart::requestDocumentation(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
