/****************************************************************************
** Meta object code from reading C++ file 'textentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.04.3/src/textentry.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9TextEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto TextEntry::qt_create_metaobjectdata<qt_meta_tag_ZN9TextEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextEntry",
        "evaluate",
        "",
        "WorksheetEntry::EvaluationOption",
        "evalOp",
        "resolveImagesAtCursor",
        "updateEntry",
        "populateMenu",
        "QMenu*",
        "menu",
        "QPointF",
        "pos",
        "convertToRawCell",
        "convertToTextEntry",
        "convertTargetChanged",
        "QAction*",
        "action",
        "updateAfterSettingsChanges",
        "handleMathRender",
        "QSharedPointer<MathRenderResult>",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool(WorksheetEntry::EvaluationOption)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'resolveImagesAtCursor'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateEntry'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'populateMenu'
        QtMocHelpers::SlotData<void(QMenu *, QPointF)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'convertToRawCell'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToTextEntry'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertTargetChanged'
        QtMocHelpers::SlotData<void(QAction *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'updateAfterSettingsChanges'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleMathRender'
        QtMocHelpers::SlotData<void(QSharedPointer<MathRenderResult>)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextEntry, qt_meta_tag_ZN9TextEntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetEntry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TextEntryE_t>.metaTypes,
    nullptr
} };

void TextEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<WorksheetEntry::EvaluationOption>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->resolveImagesAtCursor(); break;
        case 3: _t->updateEntry(); break;
        case 4: _t->populateMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 5: _t->convertToRawCell(); break;
        case 6: _t->convertToTextEntry(); break;
        case 7: _t->convertTargetChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 8: _t->updateAfterSettingsChanges(); break;
        case 9: _t->handleMathRender((*reinterpret_cast<std::add_pointer_t<QSharedPointer<MathRenderResult>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<MathRenderResult> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *TextEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TextEntryE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetEntry::qt_metacast(_clname);
}

int TextEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetEntry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
