/********************************************************************************
** Form generated from reading UI file 'advancedplotdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDPLOTDIALOG_H
#define UI_ADVANCEDPLOTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AdvancedPlotAssistantBase
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QLineEdit *expressionEdit;
    QLabel *label;
    QTabWidget *directivesTabs;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *AdvancedPlotAssistantBase)
    {
        if (AdvancedPlotAssistantBase->objectName().isEmpty())
            AdvancedPlotAssistantBase->setObjectName("AdvancedPlotAssistantBase");
        AdvancedPlotAssistantBase->resize(537, 215);
        verticalLayout = new QVBoxLayout(AdvancedPlotAssistantBase);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(AdvancedPlotAssistantBase);
        label_2->setObjectName("label_2");
        QFont font;
        font.setPointSize(10);
        font.setBold(true);
        label_2->setFont(font);

        verticalLayout->addWidget(label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(AdvancedPlotAssistantBase);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        expressionEdit = new QLineEdit(AdvancedPlotAssistantBase);
        expressionEdit->setObjectName("expressionEdit");

        horizontalLayout->addWidget(expressionEdit);


        verticalLayout->addLayout(horizontalLayout);

        label = new QLabel(AdvancedPlotAssistantBase);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        directivesTabs = new QTabWidget(AdvancedPlotAssistantBase);
        directivesTabs->setObjectName("directivesTabs");

        verticalLayout->addWidget(directivesTabs);

        buttonBox = new QDialogButtonBox(AdvancedPlotAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AdvancedPlotAssistantBase);

        QMetaObject::connectSlotsByName(AdvancedPlotAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *AdvancedPlotAssistantBase)
    {
        label_2->setText(tr2i18n("Plot", nullptr));
        label_3->setText(tr2i18n("Expression:", nullptr));
        label->setText(tr2i18n("Additional options:", nullptr));
        (void)AdvancedPlotAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class AdvancedPlotAssistantBase: public Ui_AdvancedPlotAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADVANCEDPLOTDIALOG_H

