// This file is generated by kconfig_compiler_kf6 from luabackend.kcfg.
// All changes you do to this file will be lost.
#ifndef LUASETTINGS_H
#define LUASETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <QStandardPaths>

class LuaSettings : public KConfigSkeleton
{
  public:

    static LuaSettings *self();
    ~LuaSettings() override;

    /**
      Get Path to luajit command
    */
    static
    QUrl path()
    {
      return self()->mPath;
    }

    /**
      Is Path to luajit command Immutable
    */
    static
    bool isPathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Path" ) );
    }

    /**
      Get List of scripts to autorun at the beginning of session
    */
    static
    QStringList autorunScripts()
    {
      return self()->mAutorunScripts;
    }

    /**
      Is List of scripts to autorun at the beginning of session Immutable
    */
    static
    bool isAutorunScriptsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autorunScripts" ) );
    }

  protected:
    LuaSettings();
    friend class LuaSettingsHelper;


    // LuaBackend
    QUrl mPath;
    QStringList mAutorunScripts;
};

#endif

