/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // cantor_advancedplot_assistant.rc
  0x0,0x0,0x0,0xe8,
  0x3c,
  0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,0x6b,0x70,0x61,0x72,0x74,0x67,0x75,
  0x69,0x20,0x53,0x59,0x53,0x54,0x45,0x4d,0x20,0x22,0x6b,0x70,0x61,0x72,0x74,0x67,
  0x75,0x69,0x2e,0x64,0x74,0x64,0x22,0x3e,0xa,0x3c,0x6b,0x70,0x61,0x72,0x74,0x67,
  0x75,0x69,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x63,0x61,0x6e,0x74,0x6f,0x72,0x5f,
  0x61,0x64,0x76,0x61,0x6e,0x63,0x65,0x64,0x70,0x6c,0x6f,0x74,0x5f,0x61,0x73,0x73,
  0x69,0x73,0x74,0x61,0x6e,0x74,0x22,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,
  0x22,0x31,0x22,0x3e,0xa,0x3c,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,0x3e,0xa,0x20,
  0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x50,0x6c,0x6f,
  0x74,0x22,0x3e,0x3c,0x74,0x65,0x78,0x74,0x3e,0x26,0x61,0x6d,0x70,0x3b,0x50,0x6c,
  0x6f,0x74,0x3c,0x2f,0x74,0x65,0x78,0x74,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x41,
  0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x61,0x64,0x76,0x61,
  0x6e,0x63,0x65,0x64,0x70,0x6c,0x6f,0x74,0x5f,0x61,0x73,0x73,0x69,0x73,0x74,0x61,
  0x6e,0x74,0x22,0x2f,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x3e,0xa,
  0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,0x3e,0xa,0x3c,0x2f,0x6b,0x70,0x61,
  0x72,0x74,0x67,0x75,0x69,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // cantor
  0x0,0x6,
  0x6,0x98,0x5b,0x62,
  0x0,0x63,
  0x0,0x61,0x0,0x6e,0x0,0x74,0x0,0x6f,0x0,0x72,
    // cantor_advancedplot_assistant.rc
  0x0,0x20,
  0x8,0x1a,0x1d,0xe3,
  0x0,0x63,
  0x0,0x61,0x0,0x6e,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x5f,0x0,0x61,0x0,0x64,0x0,0x76,0x0,0x61,0x0,0x6e,0x0,0x63,0x0,0x65,0x0,0x64,0x0,0x70,0x0,0x6c,
  0x0,0x6f,0x0,0x74,0x0,0x5f,0x0,0x61,0x0,0x73,0x0,0x73,0x0,0x69,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x6e,0x0,0x74,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x18,0xc2,0xc3,0x48,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x18,0xc2,0xc3,0x48,
  // :/kxmlgui5/cantor
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x18,0xc2,0xc3,0x48,
  // :/kxmlgui5/cantor/cantor_advancedplot_assistant.rc
  0x0,0x0,0x0,0x28,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x18,0xc2,0xc3,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_advancedplotassistant)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_advancedplotassistant)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_advancedplotassistant)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_advancedplotassistant)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_advancedplotassistant)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_advancedplotassistant)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
