/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Cantor.R.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef RADAPTOR_H
#define RADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "rserver.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Cantor.R
 */
class RAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Cantor.R")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Cantor.R\">\n"
"    <signal name=\"ready\"/>\n"
"    <signal name=\"statusChanged\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"status\"/>\n"
"    </signal>\n"
"    <signal name=\"expressionFinished\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"returnCode\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
"      <arg direction=\"out\" type=\"as\" name=\"files\"/>\n"
"    </signal>\n"
"    <signal name=\"inputRequested\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"prompt\"/>\n"
"    </signal>\n"
"    <signal name=\"requestAnswered\"/>\n"
"    <method name=\"runCommand\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"cmd\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"internal\"/>\n"
"    </method>\n"
"    <method name=\"answerRequest\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"answer\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    RAdaptor(RServer *parent);
    ~RAdaptor() override;

    inline RServer *parent() const
    { return static_cast<RServer *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void answerRequest(const QString &answer);
    void runCommand(const QString &cmd, bool internal);
Q_SIGNALS: // SIGNALS
    void expressionFinished(int returnCode, const QString &text, const QStringList &files);
    void inputRequested(const QString &prompt);
    void ready();
    void requestAnswered();
    void statusChanged(int status);
};

#endif
