    const char *R_VARS[] = {
        "R_ARCH","",
        "R_BROWSER","",
        "R_BZIPCMD","/usr/bin/bzip2",
        "R_DOC_DIR","/usr/share/doc/R/",
        "R_GZIPCMD","/usr/bin/gzip",
        "R_HOME","/usr/lib64/R",
        "R_INCLUDE_DIR","/usr/include/R/",
        "R_LIBS_SITE","/usr/lib64/R/site-library",
        "R_LIBS_USER","/build/R/x86_64-pc-linux-gnu-library/4.6",
        "R_PAPERSIZE","a4",
        "R_PDFVIEWER","",
        "R_PLATFORM","x86_64-pc-linux-gnu",
        "R_PRINTCMD","",
        "R_RD4PDF","times,hyper",
        "R_SHARE_DIR","/usr/share/R/",
        "R_STRIP_SHARED_LIB","strip --strip-unneeded",
        "R_STRIP_STATIC_LIB","strip --strip-debug",
        "R_TEXI2DVICMD","/usr/bin/texi2dvi",
        "R_UNZIPCMD","/usr/bin/unzip",
        "R_ZIPCMD","/usr/bin/zip",
        nullptr
    };
