/****************************************************************************
** Meta object code from reading C++ file 'extension.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../cantor-26.04.3/src/lib/extension.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'extension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Cantor9ExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::Extension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor9ExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::Extension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Extension, qt_meta_tag_ZN6Cantor9ExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::Extension::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor9ExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor9ExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor9ExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::Extension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Extension *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Cantor::Extension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::Extension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor9ExtensionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Cantor::Extension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor16HistoryExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::HistoryExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::HistoryExtension",
        "lastResult",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'lastResult'
        QtMocHelpers::SlotData<QString()>(1, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HistoryExtension, qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::HistoryExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::HistoryExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HistoryExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->lastResult();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::HistoryExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::HistoryExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor16HistoryExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::HistoryExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor15ScriptExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::ScriptExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::ScriptExtension",
        "runExternalScript",
        "",
        "path",
        "scriptFileFilter",
        "highlightingMode",
        "commandSeparator",
        "commentStartingSequence",
        "commentEndingSequence"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'runExternalScript'
        QtMocHelpers::SlotData<QString(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'scriptFileFilter'
        QtMocHelpers::SlotData<QString()>(4, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'highlightingMode'
        QtMocHelpers::SlotData<QString()>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'commandSeparator'
        QtMocHelpers::SlotData<QString()>(6, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'commentStartingSequence'
        QtMocHelpers::SlotData<QString()>(7, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'commentEndingSequence'
        QtMocHelpers::SlotData<QString()>(8, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScriptExtension, qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::ScriptExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::ScriptExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->runExternalScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->scriptFileFilter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->highlightingMode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->commandSeparator();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->commentStartingSequence();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->commentEndingSequence();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::ScriptExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::ScriptExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor15ScriptExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::ScriptExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor12CASExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::CASExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor12CASExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::CASExtension",
        "solve",
        "",
        "equations",
        "variables",
        "simplify",
        "expression",
        "expand"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'solve'
        QtMocHelpers::SlotData<QString(const QStringList &, const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QStringList, 3 }, { QMetaType::QStringList, 4 },
        }}),
        // Slot 'simplify'
        QtMocHelpers::SlotData<QString(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'expand'
        QtMocHelpers::SlotData<QString(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CASExtension, qt_meta_tag_ZN6Cantor12CASExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::CASExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor12CASExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor12CASExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor12CASExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::CASExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CASExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->solve((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->simplify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->expand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::CASExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::CASExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor12CASExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::CASExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor17CalculusExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::CalculusExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::CalculusExtension",
        "limit",
        "",
        "expression",
        "variable",
        "differentiate",
        "function",
        "times",
        "integrate",
        "left",
        "right"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'limit'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 1 },
        }}),
        // Slot 'differentiate'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, int)>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 4 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'integrate'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'integrate'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 4 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalculusExtension, qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::CalculusExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::CalculusExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalculusExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->limit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->differentiate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->integrate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->integrate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::CalculusExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::CalculusExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor17CalculusExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::CalculusExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor13PlotExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::PlotExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor13PlotExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::PlotExtension",
        "plotFunction2d",
        "",
        "function",
        "variable",
        "left",
        "right",
        "plotFunction3d",
        "VariableParameter",
        "var1",
        "var2"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'plotFunction2d'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'plotFunction3d'
        QtMocHelpers::SlotData<QString(const QString &, const VariableParameter &, const VariableParameter &)>(7, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlotExtension, qt_meta_tag_ZN6Cantor13PlotExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::PlotExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor13PlotExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor13PlotExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor13PlotExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::PlotExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlotExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->plotFunction2d((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->plotFunction3d((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<VariableParameter>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<VariableParameter>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::PlotExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::PlotExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor13PlotExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::PlotExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::AdvancedPlotExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::AdvancedPlotExtension",
        "plotFunction2d",
        "",
        "expression",
        "QList<Cantor::AdvancedPlotExtension::PlotDirective*>",
        "directives",
        "dispatchDirective",
        "Cantor::AdvancedPlotExtension::PlotDirective",
        "directive"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'plotFunction2d'
        QtMocHelpers::SlotData<QString(const QString &, const QVector<Cantor::AdvancedPlotExtension::PlotDirective*> &) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'dispatchDirective'
        QtMocHelpers::SlotData<QString(const Cantor::AdvancedPlotExtension::PlotDirective &) const>(6, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AdvancedPlotExtension, qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::AdvancedPlotExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::AdvancedPlotExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AdvancedPlotExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->plotFunction2d((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Cantor::AdvancedPlotExtension::PlotDirective*>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->dispatchDirective((*reinterpret_cast<std::add_pointer_t<Cantor::AdvancedPlotExtension::PlotDirective>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::AdvancedPlotExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::AdvancedPlotExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor21AdvancedPlotExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::AdvancedPlotExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::LinearAlgebraExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::LinearAlgebraExtension",
        "createVector",
        "",
        "entries",
        "Cantor::LinearAlgebraExtension::VectorType",
        "type",
        "nullVector",
        "size",
        "createMatrix",
        "Matrix",
        "matrix",
        "identityMatrix",
        "nullMatrix",
        "rows",
        "columns",
        "rank",
        "invertMatrix",
        "charPoly",
        "eigenVectors",
        "eigenValues"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createVector'
        QtMocHelpers::SlotData<QString(const QStringList &, Cantor::LinearAlgebraExtension::VectorType)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'nullVector'
        QtMocHelpers::SlotData<QString(int, Cantor::LinearAlgebraExtension::VectorType)>(6, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'createMatrix'
        QtMocHelpers::SlotData<QString(const Matrix &)>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'identityMatrix'
        QtMocHelpers::SlotData<QString(int)>(11, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'nullMatrix'
        QtMocHelpers::SlotData<QString(int, int)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'rank'
        QtMocHelpers::SlotData<QString(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'invertMatrix'
        QtMocHelpers::SlotData<QString(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'charPoly'
        QtMocHelpers::SlotData<QString(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'eigenVectors'
        QtMocHelpers::SlotData<QString(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'eigenValues'
        QtMocHelpers::SlotData<QString(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LinearAlgebraExtension, qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::LinearAlgebraExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::LinearAlgebraExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LinearAlgebraExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->createVector((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Cantor::LinearAlgebraExtension::VectorType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->nullVector((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Cantor::LinearAlgebraExtension::VectorType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->createMatrix((*reinterpret_cast<std::add_pointer_t<Matrix>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->identityMatrix((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->nullMatrix((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->rank((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->invertMatrix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->charPoly((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->eigenVectors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->eigenValues((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::LinearAlgebraExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::LinearAlgebraExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor22LinearAlgebraExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::LinearAlgebraExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::VariableManagementExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::VariableManagementExtension",
        "addVariable",
        "",
        "name",
        "value",
        "setValue",
        "removeVariable",
        "saveVariables",
        "fileName",
        "loadVariables",
        "clearVariables"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addVariable'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'setValue'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'removeVariable'
        QtMocHelpers::SlotData<QString(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'saveVariables'
        QtMocHelpers::SlotData<QString(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'loadVariables'
        QtMocHelpers::SlotData<QString(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'clearVariables'
        QtMocHelpers::SlotData<QString()>(10, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VariableManagementExtension, qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::VariableManagementExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::VariableManagementExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VariableManagementExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->addVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->setValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->removeVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->saveVariables((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->loadVariables((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->clearVariables();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::VariableManagementExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::VariableManagementExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor27VariableManagementExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::VariableManagementExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Cantor18PackagingExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::PackagingExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::PackagingExtension",
        "importPackage",
        "",
        "package"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'importPackage'
        QtMocHelpers::SlotData<QString(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PackagingExtension, qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::PackagingExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<Extension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>.metaTypes,
    nullptr
} };

void Cantor::PackagingExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PackagingExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->importPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Cantor::PackagingExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::PackagingExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor18PackagingExtensionE_t>.strings))
        return static_cast<void*>(this);
    return Extension::qt_metacast(_clname);
}

int Cantor::PackagingExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
