/********************************************************************************
** Form generated from reading UI file 'importpackagedlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTPACKAGEDLG_H
#define UI_IMPORTPACKAGEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ImportPackageAssistantBase
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *package;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ImportPackageAssistantBase)
    {
        if (ImportPackageAssistantBase->objectName().isEmpty())
            ImportPackageAssistantBase->setObjectName("ImportPackageAssistantBase");
        ImportPackageAssistantBase->resize(303, 102);
        gridLayout = new QGridLayout(ImportPackageAssistantBase);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ImportPackageAssistantBase);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        package = new KLineEdit(ImportPackageAssistantBase);
        package->setObjectName("package");

        gridLayout->addWidget(package, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(ImportPackageAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 1, 1, 1);


        retranslateUi(ImportPackageAssistantBase);

        QMetaObject::connectSlotsByName(ImportPackageAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *ImportPackageAssistantBase)
    {
        label->setText(tr2i18n("Package:", nullptr));
        (void)ImportPackageAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class ImportPackageAssistantBase: public Ui_ImportPackageAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTPACKAGEDLG_H

