/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "keditlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_KAlgebraSettingsBase
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayoutScripts;
    KEditListWidget *kcfg_autorunScripts;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KAlgebraSettingsBase)
    {
        if (KAlgebraSettingsBase->objectName().isEmpty())
            KAlgebraSettingsBase->setObjectName("KAlgebraSettingsBase");
        KAlgebraSettingsBase->resize(400, 300);
        verticalLayout = new QVBoxLayout(KAlgebraSettingsBase);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(KAlgebraSettingsBase);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        verticalLayoutScripts = new QVBoxLayout(groupBox);
        verticalLayoutScripts->setObjectName("verticalLayoutScripts");
        kcfg_autorunScripts = new KEditListWidget(groupBox);
        kcfg_autorunScripts->setObjectName("kcfg_autorunScripts");

        verticalLayoutScripts->addWidget(kcfg_autorunScripts);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(KAlgebraSettingsBase);

        QMetaObject::connectSlotsByName(KAlgebraSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *KAlgebraSettingsBase)
    {
#if QT_CONFIG(tooltip)
        groupBox->setToolTip(tr2i18n("This autorun commands, which will run on start new worksheet. They can be useful for loading needed modules, changing environment, etc.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Commands to autorun", nullptr));
        (void)KAlgebraSettingsBase;
    } // retranslateUi

};

namespace Ui {
    class KAlgebraSettingsBase: public Ui_KAlgebraSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

