/********************************************************************************
** Form generated from reading UI file 'plottitle.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOTTITLE_H
#define UI_PLOTTITLE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PlotTitleControl
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *titleEdit;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PlotTitleControl)
    {
        if (PlotTitleControl->objectName().isEmpty())
            PlotTitleControl->setObjectName("PlotTitleControl");
        PlotTitleControl->resize(400, 300);
        verticalLayout = new QVBoxLayout(PlotTitleControl);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(PlotTitleControl);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        titleEdit = new QLineEdit(PlotTitleControl);
        titleEdit->setObjectName("titleEdit");

        horizontalLayout->addWidget(titleEdit);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(PlotTitleControl);

        QMetaObject::connectSlotsByName(PlotTitleControl);
    } // setupUi

    void retranslateUi(QWidget *PlotTitleControl)
    {
        label->setText(tr2i18n("Plot title:", nullptr));
        (void)PlotTitleControl;
    } // retranslateUi

};

namespace Ui {
    class PlotTitleControl: public Ui_PlotTitleControl {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOTTITLE_H

