/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "keditlistwidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_LuaSettingsBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QGridLayout *gridLayout;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QSpacerItem *verticalSpacer;
    QWidget *tabAutorun;
    QVBoxLayout *verticalLayout;
    QLabel *lAutorun;
    KEditListWidget *kcfg_autorunScripts;
    QWidget *tabDocumentation;

    void setupUi(QWidget *LuaSettingsBase)
    {
        if (LuaSettingsBase->objectName().isEmpty())
            LuaSettingsBase->setObjectName("LuaSettingsBase");
        LuaSettingsBase->resize(420, 302);
        verticalLayout_2 = new QVBoxLayout(LuaSettingsBase);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tabWidget = new QTabWidget(LuaSettingsBase);
        tabWidget->setObjectName("tabWidget");
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        gridLayout = new QGridLayout(tabGeneral);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(tabGeneral);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_Path = new KUrlRequester(tabGeneral);
        kcfg_Path->setObjectName("kcfg_Path");

        gridLayout->addWidget(kcfg_Path, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        tabWidget->addTab(tabGeneral, QString());
        tabAutorun = new QWidget();
        tabAutorun->setObjectName("tabAutorun");
        verticalLayout = new QVBoxLayout(tabAutorun);
        verticalLayout->setObjectName("verticalLayout");
        lAutorun = new QLabel(tabAutorun);
        lAutorun->setObjectName("lAutorun");
        lAutorun->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(lAutorun);

        kcfg_autorunScripts = new KEditListWidget(tabAutorun);
        kcfg_autorunScripts->setObjectName("kcfg_autorunScripts");

        verticalLayout->addWidget(kcfg_autorunScripts);

        tabWidget->addTab(tabAutorun, QString());
        tabDocumentation = new QWidget();
        tabDocumentation->setObjectName("tabDocumentation");
        tabWidget->addTab(tabDocumentation, QString());

        verticalLayout_2->addWidget(tabWidget);


        retranslateUi(LuaSettingsBase);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(LuaSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *LuaSettingsBase)
    {
        label->setText(tr2i18n("Path to luajit:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("General", nullptr));
        lAutorun->setText(tr2i18n("Commands to autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAutorun), tr2i18n("Autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDocumentation), tr2i18n("Documentation", nullptr));
        (void)LuaSettingsBase;
    } // retranslateUi

};

namespace Ui {
    class LuaSettingsBase: public Ui_LuaSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

